# - Try to find libpcap include dirs and libraries
#
# Usage of this module as follows:
#
#     find_package(PCAP)
#
# Variables used by this module, they can change the default behaviour and need
# to be set before calling find_package:
#
#  PCAP_ROOT_DIR             Set this variable to the root installation of
#                            libpcap if the module has problems finding the
#                            proper installation path.
#
# Variables defined by this module:
#
#  PCAP_FOUND                System has libpcap, include and library dirs found
#  PCAP_INCLUDE_DIR          The libpcap include directories.
#  PCAP_LIBRARY              The libpcap library

find_path(PCAP_ROOT_DIR NAMES include/pcap.h)
find_path(PCAP_INCLUDE_DIR NAMES pcap.h HINTS ${PCAP_ROOT_DIR}/include)
find_library(PCAP_LIBRARY NAMES pcap HINTS ${PCAP_ROOT_DIR}/lib)

include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(PCAP DEFAULT_MSG PCAP_ROOT_DIR)

mark_as_advanced(
        PCAP_ROOT_DIR
        PCAP_INCLUDE_DIR
        PCAP_LIBRARY
)

if(PCAP_FOUND)
    add_library(PCAP::PCAP INTERFACE IMPORTED)
    set_property(TARGET PCAP::PCAP PROPERTY INTERFACE_INCLUDE_DIRECTORIES ${PCAP_INCLUDE_DIR})
    set_property(TARGET PCAP::PCAP PROPERTY INTERFACE_LINK_LIBRARIES ${PCAP_LIBRARY})
endif()
